=======
Whalrus
=======


.. image:: https://img.shields.io/pypi/v/whalrus.svg
        :target: https://pypi.python.org/pypi/whalrus
        :alt: PyPI Status

.. image:: https://github.com/francois-durand/whalrus/workflows/build/badge.svg?branch=master
        :target: https://github.com/francois-durand/whalrus/actions?query=workflow%3Abuild
        :alt: Build Status

.. image:: https://github.com/francois-durand/whalrus/workflows/docs/badge.svg?branch=master
        :target: https://github.com/francois-durand/whalrus/actions?query=workflow%3Adocs
        :alt: Documentation Status

.. image:: https://codecov.io/gh/francois-durand/whalrus/branch/master/graphs/badge.svg
        :target: https://codecov.io/gh/francois-durand/whalrus/branch/master/graphs
        :alt: Code Coverage



Which Alternative Represents Us, a package for voting rules


* Free software: GNU General Public License v3
* Documentation: https://francois-durand.github.io/whalrus/.

--------
Features
--------

* TODO

-------
Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

We use the checklist provided by `My Toy Package`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`My Toy Package`: https://my-toy-package.readthedocs.io/en/latest/readme.html
